==> 0.5.4.zip: saneeconomy/SaneEconomyCore/src/main/java/org/appledash/saneeconomy/command/type/BalanceCommand.java <==
package org.appledash.saneeconomy.command.type;

import org.appledash.saneeconomy.SaneEconomy;
import org.appledash.saneeconomy.command.SaneEconomyCommand;
import org.appledash.saneeconomy.command.exception.CommandException;
import org.appledash.saneeconomy.command.exception.type.usage.NeedPlayerException;
import org.appledash.saneeconomy.utils.MessageUtils;
import org.bukkit.Bukkit;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

/**
 * Created by AppleDash on 6/13/2016.
 * Blackjack is still best pony.
 */
public class BalanceCommand extends SaneEconomyCommand {
    @Override
    public String getPermission() {
        return "saneeconomy.balance";
    }

    @Override
    public String[] getUsage() {
        return new String[] {
                "/<command> [player]"
        };
    }

    @Override
    public void onCommand(CommandSender sender, String[] args) throws CommandException {
        String playerName;

        if (args.length == 0) {
            if (!(sender instanceof Player)) {
                throw new NeedPlayerException();
            }

            playerName = sender.getName();
        } else {
            playerName = args[0];

            if (!sender.hasPermission("saneeconomy.balance.other")) {
                MessageUtils.sendMessage(sender, "You don't have permission to check the balance of %s.", playerName);
                return;
            }
        }

        Player player = Bukkit.getServer().getPlayer(playerName);

        if (player == null) {
            MessageUtils.sendMessage(sender, "That player is not online.");
            return;
        }

        MessageUtils.sendMessage(sender, "Balance for %s is %s.", playerName, SaneEconomy.getInstance().getEconomyManager().getFormattedBalance(player));
    }
}

==> 0.6.3.zip: saneeconomy/SaneEconomyCore/src/main/java/org/appledash/saneeconomy/command/type/BalanceCommand.java <==
package org.appledash.saneeconomy.command.type;

import org.appledash.saneeconomy.SaneEconomy;
import org.appledash.saneeconomy.command.SaneEconomyCommand;
import org.appledash.saneeconomy.command.exception.CommandException;
import org.appledash.saneeconomy.command.exception.type.usage.NeedPlayerException;
import org.appledash.saneeconomy.economy.economable.Economable;
import org.appledash.saneeconomy.utils.MessageUtils;
import org.appledash.saneeconomy.utils.PlayerUtils;
import org.bukkit.OfflinePlayer;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

/**
 * Created by AppleDash on 6/13/2016.
 * Blackjack is still best pony.
 */
public class BalanceCommand extends SaneEconomyCommand {
    @Override
    public String getPermission() {
        return "saneeconomy.balance";
    }

    @Override
    public String[] getUsage() {
        return new String[] {
                "/<command> [player]"
        };
    }

    @Override
    public void onCommand(CommandSender sender, String[] args) throws CommandException {
        String playerName;

        if (args.length == 0) {
            if (!(sender instanceof Player)) {
                throw new NeedPlayerException();
            }

            playerName = sender.getName();
        } else {
            playerName = args[0];

            if (!sender.hasPermission("saneeconomy.balance.other")) {
                MessageUtils.sendMessage(sender, "You don't have permission to check the balance of %s.", playerName);
                return;
            }
        }

        OfflinePlayer player = PlayerUtils.getOfflinePlayer(playerName);

        if (player == null) {
            MessageUtils.sendMessage(sender, "That player does not exist.");
            return;
        }

        MessageUtils.sendMessage(sender, "Balance for %s is %s.", playerName, SaneEconomy.getInstance().getEconomyManager().getFormattedBalance(Economable.wrap(player)));
    }
}
